@@ -7,6 +7,7 @@ from kaizen.llms.prompts.code_review_prompts import (
     PR_DESCRIPTION_PROMPT,
     FILE_CODE_REVIEW_PROMPT,
     MERGE_PR_DESCRIPTION_PROMPT,
+    PR_FILE_DESCRIPTION_PROMPT,
 )
 import logging
 import json
@@ -62,7 +63,10 @@ class CodeReviewer:
             PULL_REQUEST_DESC=pull_request_desc,
             CODE_DIFF=diff_text,
         )
-        total_usage = None
+        total_usage = {
+            "prompt_tokens": 0,
+            "completion_tokens": 0
+        }
         if self.provider.is_inside_token_limit(PROMPT=prompt):
             self.logger.debug("Processing Directly from Diff")
             resp, usage = self.provider.chat_completion(prompt, user=user)
@@ -85,6 +89,9 @@ class CodeReviewer:
                         PULL_REQUEST_DESC=pull_request_desc,
                         FILE_PATCH=patch_details,
                     )
+                    if self.provider.is_inside_token_limit(PROMPT=prompt, percentage=85):
+                        # TODO: Chunk this big files and process them
+                        continue
                     resp, usage = self.provider.chat_completion(prompt, user=user)
                     total_usage = self.provider.update_usage(total_usage, usage)
                     review_json = parser.extract_json(resp)
@@ -120,7 +127,10 @@ class CodeReviewer:
             CODE_DIFF=diff_text,
         )
 
-        total_usage = None
+        total_usage = {
+            "prompt_tokens": 0,
+            "completion_tokens": 0
+        }
         if self.provider.is_inside_token_limit(PROMPT=prompt):
             self.logger.debug("Processing Directly from Diff")
             resp, usage = self.provider.chat_completion(prompt, user=user)
@@ -137,11 +147,14 @@ class CodeReviewer:
                     filename.split(".")[-1] not in parser.EXCLUDED_FILETYPES
                     and patch_details is not None
                 ):
-                    prompt = PR_DESCRIPTION_PROMPT.format(
+                    prompt = PR_FILE_DESCRIPTION_PROMPT.format(
                         PULL_REQUEST_TITLE=pull_request_title,
                         PULL_REQUEST_DESC=pull_request_desc,
                         CODE_DIFF=patch_details,
                     )
+                    if self.provider.is_inside_token_limit(PROMPT=prompt):
+                        # TODO: Chunk this big files and process them
+                        continue
                     resp, usage = self.provider.chat_completion(prompt, user=user)
                     total_usage = self.provider.update_usage(total_usage, usage)
                     desc_json = parser.extract_json(resp)
@@ -189,7 +202,7 @@ class CodeReviewer:
                         start_line=review.get("start_line", "NA"),
                         end_line=review.get("end_line", "NA"),
                         file_name=review.get("file_name", "NA"),
-                        request_for_change=review.get('request_for_change', 'NA')
+                        request_for_change=review.get("request_for_change", "NA"),
                     )
                     markdown_output += ct + "\n"
 
